<?php
/**
 * Template parts.
 *
 * @package Highend
 * @since   3.5.0
 */

/**
 * Do not allow direct script access.
 */
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! function_exists( 'highend_testimonial_box' ) ) :

	/**
	 * Display Testimonial Box. Based on deprecated hb_testimonial_box.
	 *
	 * @since 3.5.0
	 */
	function highend_testimonial_box( $post_id ) {

		$post = get_post( $post_id );

		if ( ! $post ) {
			return;
		}

		// Setup post.
		setup_postdata( $post );

		$author_image     = vp_metabox('testimonial_type_settings.hb_testimonial_author_image');
		$author_name      = vp_metabox('testimonial_type_settings.hb_testimonial_author');
		$author_desc      = vp_metabox('testimonial_type_settings.hb_testimonial_description');
		$author_desc_link = vp_metabox('testimonial_type_settings.hb_testimonial_description_link');
		?>
		
		<div class="hb-testimonial">
			<?php the_content(); ?>
		</div>
							
		<?php 
		if ( $author_image ) {

			$author_image = highend_resize( $author_image, 60, 60 );

			if ( $author_image['url'] ) {
				echo '<img src="' . esc_url( $author_image['url'] ) . '" width="60" height="60" class="testimonial-author-img"/>';
			}
		}

		if ( $author_name || $author_desc ) {

			echo '<div class="testimonial-author">';
			
			if ( $author_name ) {
				echo '<h5 class="testimonial-author-name">' . esc_html( $author_name ) . '</h5>';
			}

			if ( $author_desc ) {
				$author_desc_link = $author_desc_link ? ' href="' . esc_url( $author_desc_link ) . '"' : '';
				echo '<a class="testimonial-company"' . $author_desc_link . '>' . esc_html( $author_desc ) . '</a>';
			}

			echo '</div>';
		}

		// Reset postdata.
		wp_reset_postdata();
	}
endif;

if ( ! function_exists( 'highend_testimonial_quote' ) ) :

	/**
	 * Display Testimonial Quote. Based on deprecated hb_testimonial_quote.
	 *
	 * @since 3.5.0
	 */
    function highend_testimonial_quote( $post_id ) {

		$post = get_post( $post_id );

		if ( ! $post ) {
			return;
		}

		// Setup postdata.
		setup_postdata( $post );

		$author_name      = vp_metabox('testimonial_type_settings.hb_testimonial_author');
		$author_desc      = vp_metabox('testimonial_type_settings.hb_testimonial_description');
		$author_desc_link = vp_metabox('testimonial_type_settings.hb_testimonial_description_link');
		?>
		<p><?php the_content(); ?></p>

		<div class="testimonial-quote-meta">
			<span>
				<?php 
				if ( $author_name ) {
					echo esc_html( $author_name );
				}

				if ( $author_desc ) {
					if ( $author_desc_link ) {
						echo ', <a href="' . esc_url( $author_desc_link ) . '">' . esc_html( $author_desc ) . '</a>';
					} else {
						echo ', ' . esc_html( $author_desc );
					}
				}
				?>
			</span>
		</div>
		 
		<?php 
		// Reset postdata.
		wp_reset_postdata();
	}
endif;

if ( ! function_exists( 'highend_team_member_box' ) ) :

	/**
	 * Display Team Member Box. Based on deprecated hb_team_member_box.
	 *
	 * @since 3.5.0
	 */
	function highend_team_member_box( $post_id , $style = "", $excerpt_length = 20 ) {

		$post = get_post( $post_id );

		if ( ! $post ) {
			return;
		}
		
		// Setup postdata.
		setup_postdata( $post );

		$thumb = get_post_thumbnail_id();
		$style = '' !== $style ? ' tmb-2' : $style;
		?>

		<div class="team-member-box<?php echo esc_attr( $style ); ?>">
									
			<div class="team-member-img">

				<?php 
				if ( $thumb ) {
					$image        = highend_resize( $thumb, 350, 350 );
					$social_links = highend_get_social_networks_array();

					if ( $image['url'] ) {
						echo '<img src="' . esc_url( $image['url'] ) . '" alt="' . esc_attr( get_the_title() ) . '"/>';
					}
					?>

					<ul class="social-icons dark">
					
						<?php foreach ( $social_links as $soc_id => $soc_name ) { ?>

							<?php 
							if ( ! vp_metabox('team_member_settings.hb_employee_social_' . $soc_id ) ) {
								continue;
							}
							?>

							<li class="<?php echo esc_attr( $soc_id ); ?>">

								<?php if ( ! in_array( $soc_id, array( 'behance', 'vk', 'envelop', 'sn500px', 'weibo', 'tripadvisor' ) ) ) { ?>
									<a href="<?php echo esc_url( vp_metabox('team_member_settings.hb_employee_social_' . $soc_id ) ); ?>" target="_blank">
										<i class="hb-moon-<?php echo esc_attr( $soc_id ); ?>"></i>
										<i class="hb-moon-<?php echo esc_attr( $soc_id ); ?>"></i>
									</a>
								<?php } elseif ( 'envelop' === $soc_id ) { ?>
									<a href="mailto:<?php echo sanitize_email( vp_metabox('team_member_settings.hb_employee_social_' . $soc_id ) ); ?>">
										<i class="hb-moon-<?php echo esc_attr( $soc_id ); ?>"></i>
										<i class="hb-moon-<?php echo esc_attr( $soc_id ); ?>"></i>
									</a>
								<?php } else { ?>
									<a href="<?php echo esc_url( vp_metabox('team_member_settings.hb_employee_social_' . $soc_id ) ); ?>" target="_blank">
										<i class="icon-<?php echo esc_attr( $soc_id ); ?>"></i>
										<i class="icon-<?php echo esc_attr( $soc_id ); ?>"></i>
									</a>
								<?php } ?>

							</li>

						<?php } ?>
					</ul>

				<?php } ?>
			</div><!-- END .team-member-img -->
										
			<div class="team-member-description">

				<div class="team-header-info clearfix">

					<div class="team-name">
						<h4 class="team-member-name"><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h4>

						<?php if ( vp_metabox('team_member_settings.hb_employee_position') ) { ?>
							<p class="team-position"><?php echo esc_html( vp_metabox('team_member_settings.hb_employee_position') ); ?></p>
						<?php } ?>
					</div><!-- END .team-name -->
												
												
				</div><!-- END .team-header-info -->

				<?php echo '<div class="spacer" style="height:10px;"></div>'; ?>

				<div class="team-member-content">
					<?php 
					if ( has_excerpt() ) {
						echo '<p class="nbm">' . get_the_excerpt() . '</p>';
						echo '<div class="spacer" style="height:15px;"></div>';
					}
					else {
						echo '<div class="spacer" style="height:15px;"></div>';
						echo '<p class="nbm">' . wp_trim_words( strip_shortcodes( get_the_content() ), $excerpt_length, NULL ) . '</p>';
					}
					?>
				</div><!-- END .team-member-content -->

				<a class="simple-read-more" href="<?php the_permalink(); ?>" target="_self"><?php esc_html_e( 'View Profile', 'hbthemes' ); ?></a>
			</div><!-- END .team-member-description -->	

		</div><!-- END .team-member-box -->

		<?php
		// Reset postdata.
		wp_reset_postdata();
	}
endif;

if ( ! function_exists( 'highend_mobile_menu' ) ) :
	/**
	 * Display Mobile menu.
	 *
	 * @since 3.5.0
	 */
	function highend_mobile_menu( $echo = true ) {

		$class = hb_options( 'hb_interactive_mobile_dropdown' ) ? ' interactive' : '';
		$class = apply_filters( 'highend_mobile_menu_nav_class', $class );

		if ( vp_metabox( 'misc_settings.hb_onepage_also' ) ) {
			$args = array(
				'echo'           => false,
				'theme_location' => 'one-page-menu',
				'menu_class'     => 'menu-main-menu-container',
				'fallback_cb'    => ''
			);   
		} else {
			if ( has_nav_menu( 'mobile-menu' ) ) {
				$args = array(
					'echo'           => false,
					'theme_location' => 'mobile-menu',
					'menu_class'     => 'menu-main-menu-container',
					'fallback_cb'    => ''
				);
			} else {
				$args = array(
					'echo'           => false,
					'theme_location' => 'main-menu',
					'menu_class'     => 'menu-main-menu-container',
					'fallback_cb'    => ''
				);
			}
		}

		$output = '<div id="mobile-menu-wrap">';

		if ( hb_options( 'hb_search_in_menu' ) ) {
			$output .= '<form method="get" class="mobile-search-form" action="' . esc_url( home_url() ) . '/"><input type="text" placeholder="' . esc_html__( 'Search', 'hbthemes' ) . '" name="s" autocomplete="off" /></form>';
		} else {
			$output .= '<div class="hb-top-holder"></div>';
		}

		// Close icon.
		$output .= '<a class="mobile-menu-close"><i class="hb-icon-x"></i></a>';
		
		// Cart widget.
		if ( class_exists( 'Woocommerce' ) && hb_options( 'hb_enable_sticky_shop_button' ) ) {
			global $woocommerce;
			$output .= '<a class="mobile-menu-shop" href="' . esc_url( wc_get_cart_url() ) . '"><i class="hb-icon-cart"></i><span class="hb-cart-total-header">' . $woocommerce->cart->get_cart_total() . '</span></a>';
		}

		// Menu navigation.
		$output .= '<nav id="mobile-menu" class="clearfix' . esc_attr( $class ) . '">';
									
		if ( function_exists( 'wp_nav_menu' ) ) {
			$output .= wp_nav_menu( $args );
		}
		$output .= '</nav>';

		$output .= '</div><!-- END #mobile-menu-wrap -->';

		$output = apply_filters( 'highend_mobile_menu', $output );

		if ( $echo ) {
			echo $output;
		} else {
			return $output;
		}
	}
endif;

if ( ! function_exists( 'highend_pagination_ajax' ) ) :
	/**
	 * Infinite Scroll/Load More pagination.
	 *
	 * @since 3.5.0
	 */
	function highend_pagination_ajax( $post_id ) {
		?>
		<a class="load-more-posts" href="#" data-postid="<?php echo esc_attr( $post_id ); ?>" data-template="<?php echo esc_attr( highend_get_page_template( $post_id ) ); ?>">
			<span class="load-more-text"><?php esc_html_e( 'Load More Posts', 'hbthemes' ); ?></span>
			<span class="hb-spin non-visible"><i class="hb-moon-spinner-5"></i></span>
		</a>
		<?php
	}
endif;

if ( ! function_exists( 'highend_load_more_posts' ) ) :
	/**
	 * Infinite Scroll/Load More pagination.
	 *
	 * @since 3.5.0
	 */
	function highend_load_more_posts() {

		check_ajax_referer( 'highend_nonce' );

		$post_id = isset( $_POST['post_id'] ) ? sanitize_text_field( $_POST['post_id'] ) : false;
		$paged   = isset( $_POST['paged'] ) ? sanitize_text_field( $_POST['paged'] ) : false;
		$template = isset( $_POST['template'] ) ? sanitize_text_field( $_POST['template'] ) : 'blog';

		if ( is_singular( $post_id ) ) {
			$args = highend_get_blog_query_args( $post_id );
		} else {
			$args = array(
				'post_status' => array( 'publish' ),
			);
		}

		$args['paged'] = $paged;

		query_posts( $args );

		if ( have_posts() ) :
			do_action( 'highend_blog_loop', $template );
		endif;

		wp_reset_query();
		
		exit;
	}
endif;
add_action( 'wp_ajax_highend_pagination_ajax', 'highend_load_more_posts' );
add_action( 'wp_ajax_nopriv_highend_pagination_ajax', 'highend_load_more_posts' );

if ( ! function_exists( 'highend_pagination' ) ) :
	/**
	 * Display Pagination.
	 *
	 * @since 3.5.1
	 */
	function highend_pagination( $post_id = '' ) {

		$template = highend_get_page_template( $post_id );

		$type = hb_options( 'hb_pagination_style' );

		// Check post metabox.
		if ( ! empty( $post_id ) ) {

			$_type = '';

			// Blog & Blog small.
			if ( 'blog' === $template || 'blog-small' === $template ) {
				$_type = vp_metabox( 'blog_page_settings.hb_pagination_style', '', $post_id );
			} elseif ( 'blog-minimal' === $template ) {
				$_type = vp_metabox( 'blog_page_minimal_settings.hb_pagination_style', '', $post_id );
			} elseif ( 'blog-grid' === $template ) {
				$_type = vp_metabox( 'blog_grid_page_settings.hb_pagination_style', '', $post_id );
			} elseif ( 'blog-grid-fullwidth' === $template ) {
				$_type = vp_metabox( 'blog_fw_page_settings.hb_pagination_style', '', $post_id );
			}

			if ( ! empty( $_type ) ) {
				$type = $_type;
			}
		}

		if ( 'ajax' === $type ) {
			highend_pagination_ajax( $post_id );
		} else {
			highend_pagination_standard();
		}
	}
endif;

/**
 * Main Content Start.
 *
 * @since 3.5.1
 */
function highend_main_content_start() {

	$layout = highend_get_page_layout();

	if ( 'fullwidth' !== $layout ) {
		echo '<div class="hb-main-content col-9 hb-equal-col-height">';
	} else {
		echo '<div class="hb-main-content col-12">';
	}
}
add_action( 'highend_main_content_start', 'highend_main_content_start' );

/**
 * Main Content End.
 *
 * @since 3.5.1
 */
function highend_main_content_end() {

	echo '</div><!-- END .hb-main-content -->';

	$layout = highend_get_page_layout();

	if ( 'fullwidth' !== $layout ) {

		$sidebar = hb_options( 'hb_choose_sidebar' );

		if ( is_singular() ) {
			$_sidebar = vp_metabox( 'layout_settings.hb_choose_sidebar' );

			if ( ! empty( $_sidebar ) && 'default' !== $_sidebar ) {
				$sidebar = $_sidebar;
			}
		}
	
		echo '<div class="hb-sidebar col-3 hb-equal-col-height">';
			
		if ( $sidebar && function_exists( 'dynamic_sidebar' ) ) {
			dynamic_sidebar( $sidebar );
		}

		echo '</div><!-- END .hb-sidebar -->';
	}
}
add_action( 'highend_main_content_end', 'highend_main_content_end' );

/**
 * Blog HTML output.
 *
 * @since 3.5.1
 */
function highend_blog_output( $template = '', $post_id = '' ) {

	if ( have_posts() ) : 
	?>
		<div id="hb-blog-posts" class="<?php highend_blog_class( $template, $post_id ); ?>"<?php highend_blog_attributes( $template, $post_id ); ?> itemprop="mainContentOfPage" itemscope="itemscope" itemtype="http://schema.org/Blog">

			<?php do_action( 'highend_before_blog_loop' ); ?>
			<?php do_action( 'highend_blog_loop', $template ); ?>
			<?php do_action( 'highend_after_blog_loop' ); ?>

		</div><!-- END #hb-blog-posts -->

		<?php highend_pagination( $post_id ); ?>
	
	<?php
	else :
		get_template_part( 'template-parts/content/content', 'none' );
	endif;
}
add_action( 'highend_blog', 'highend_blog_output', 10, 2 );

/**
 * Blog loop.
 *
 * @since 3.5.1
 */
function highend_blog_loop( $template = '' ) {
	while ( have_posts() ) : the_post();
		get_template_part( 'template-parts/entry/entry', $template );
	endwhile;
}
add_action( 'highend_blog_loop', 'highend_blog_loop' );

/**
 * Before blog listing section. Print more info on non-singular pages.
 *
 * @since 3.5.1
 */
function highend_before_blog_listing() {

	$separator = '<div class="hb-separator extra-space"><div class="hb-fw-separator"></div></div>';

	if ( is_author() ) {
		get_template_part( 'includes/post', 'author-info' );
		echo $separator;
	} elseif ( is_category() && category_description() ) {
		echo category_description();
		echo $separator;
	} elseif ( is_tag() && tag_description() ) {		
		echo tag_description();
		echo $separator;
	} elseif ( is_search() ) {
		?>
		<div class="aligncenter refine-search-wrapper">
			<h4 class="title-class semi-bold"><?php esc_html_e( 'Not happy with the results?', 'hbthemes' ); ?></h4>
			<h5 class="lighter-text"><?php esc_html_e( 'Type your search again', 'hbthemes' ); ?></h5>
			<?php get_search_form(); ?>
		</div>
		<?php
		echo $separator;
	}	
}
add_action( 'highend_main_content_start', 'highend_before_blog_listing', 20 );
